==> ringtone_helper-0.0.1.tar.gz: android/src/main/java/com/dacarnix/ringtone_helper/RingtoneHelperPlugin.java <==
package com.dacarnix.ringtone_helper;

import android.content.Context;
import android.media.AudioManager;
import android.app.Activity;
import android.content.Intent;
import android.provider.Settings;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** RingtoneHelperPlugin */
public class RingtoneHelperPlugin implements MethodCallHandler {
	private final Activity activity;

	private RingtoneHelperPlugin(Activity activity)
	{
		this.activity = activity;
	}

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "ringtone_helper");
    channel.setMethodCallHandler(new RingtoneHelperPlugin(registrar.activity()));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
		if (call.method.equals("openSoundSettings")) {
			try {
				final Intent intent = new Intent(Settings.ACTION_SOUND_SETTINGS);
				activity.startActivity(intent);
				result.success(true);
			} catch (Exception e) {
				result.success(false);
			}
		}
		else if (call.method.equals("getRingtoneSoundPath")) {
      result.success(android.os.Environment.DIRECTORY_RINGTONES);
    } 
    else if (call.method.equals("getNotificationSoundPath")) {
      result.success(android.os.Environment.DIRECTORY_NOTIFICATIONS);
    } else {
      result.notImplemented();
    }
  }
}

==> ringtone_helper-0.0.2.tar.gz: android/src/main/java/com/dacarnix/ringtone_helper/RingtoneHelperPlugin.java <==
package com.dacarnix.ringtone_helper;

import android.content.Context;
import android.media.AudioManager;
import android.app.Activity;
import android.content.Intent;
import android.provider.Settings;
import android.net.Uri;
import android.media.MediaScannerConnection;

import io.flutter.plugin.common.MethodCall;
import io.flutter.plugin.common.MethodChannel;
import io.flutter.plugin.common.MethodChannel.MethodCallHandler;
import io.flutter.plugin.common.MethodChannel.Result;
import io.flutter.plugin.common.PluginRegistry.Registrar;

/** RingtoneHelperPlugin */
public class RingtoneHelperPlugin implements MethodCallHandler {
  private final Activity activity;
  private final Registrar registrar;

	private RingtoneHelperPlugin(Registrar registrar, Activity activity)
	{
    this.registrar = registrar;
		this.activity = activity;
	}

  /** Plugin registration. */
  public static void registerWith(Registrar registrar) {
    final MethodChannel channel = new MethodChannel(registrar.messenger(), "ringtone_helper");
    channel.setMethodCallHandler(new RingtoneHelperPlugin(registrar, registrar.activity()));
  }

  @Override
  public void onMethodCall(MethodCall call, Result result) {
		if (call.method.equals("openSoundSettings")) {
			try {
				final Intent intent = new Intent(Settings.ACTION_SOUND_SETTINGS);
				activity.startActivity(intent);
				result.success(true);
			} catch (Exception e) {
				result.success(false);
			}
    }
    else if (call.method.equals("scanNewFile")) {
      try {
        String file = call.argument("filePath");
        MediaScannerConnection.scanFile(registrar.context().getApplicationContext(),
        new String[] { file }, null,
        new MediaScannerConnection.OnScanCompletedListener() {
          public void onScanCompleted(String path, Uri uri) {
          }
      });
				result.success(true);
			} catch (Exception e) {
				result.success(false);
			}
    }
		else if (call.method.equals("getRingtoneSoundPath")) {
      result.success(android.os.Environment.DIRECTORY_RINGTONES);
    } 
    else if (call.method.equals("getNotificationSoundPath")) {
      result.success(android.os.Environment.DIRECTORY_NOTIFICATIONS);
    } else {
      result.notImplemented();
    }
  }
}
